@@ -57,27 +57,27 @@ TQextScintilla::TQextScintilla(TQWidget *parent,const char *name,WFlags f)
       showSingle(FALSE), modified(FALSE), explicit_fillups(FALSE),
       fillups_enabled(FALSE), saved_fillups("")
 {
-    connect(this,TQT_SIGNAL(SCN_MODIFYATTEMPTRO()),
-             TQT_SIGNAL(modificationAttempted()));
+    connect(this,TQ_SIGNAL(SCN_MODIFYATTEMPTRO()),
+             TQ_SIGNAL(modificationAttempted()));
 
-    connect(this,TQT_SIGNAL(SCN_MODIFIED(int,int,const char *,int,int,int,int,int)),
-             TQT_SLOT(handleModified(int,int,const char *,int,int,int,int,int)));
-    connect(this,TQT_SIGNAL(SCN_CALLTIPCLICK(int)),
-             TQT_SLOT(handleCallTipClick(int)));
-    connect(this,TQT_SIGNAL(SCN_CHARADDED(int)),
-             TQT_SLOT(handleCharAdded(int)));
-    connect(this,TQT_SIGNAL(SCN_MARGINCLICK(int,int,int)),
-             TQT_SLOT(handleMarginClick(int,int,int)));
-    connect(this,TQT_SIGNAL(SCN_SAVEPOINTREACHED()),
-             TQT_SLOT(handleSavePointReached()));
-    connect(this,TQT_SIGNAL(SCN_SAVEPOINTLEFT()),
-             TQT_SLOT(handleSavePointLeft()));
-    connect(this,TQT_SIGNAL(SCN_UPDATEUI()),
-             TQT_SLOT(handleUpdateUI()));
-    connect(this,TQT_SIGNAL(TQSCN_SELCHANGED(bool)),
-             TQT_SLOT(handleSelectionChanged(bool)));
-    connect(this,TQT_SIGNAL(SCN_USERLISTSELECTION(const char *,int)),
-             TQT_SLOT(handleUserListSelection(const char *,int)));
+    connect(this,TQ_SIGNAL(SCN_MODIFIED(int,int,const char *,int,int,int,int,int)),
+             TQ_SLOT(handleModified(int,int,const char *,int,int,int,int,int)));
+    connect(this,TQ_SIGNAL(SCN_CALLTIPCLICK(int)),
+             TQ_SLOT(handleCallTipClick(int)));
+    connect(this,TQ_SIGNAL(SCN_CHARADDED(int)),
+             TQ_SLOT(handleCharAdded(int)));
+    connect(this,TQ_SIGNAL(SCN_MARGINCLICK(int,int,int)),
+             TQ_SLOT(handleMarginClick(int,int,int)));
+    connect(this,TQ_SIGNAL(SCN_SAVEPOINTREACHED()),
+             TQ_SLOT(handleSavePointReached()));
+    connect(this,TQ_SIGNAL(SCN_SAVEPOINTLEFT()),
+             TQ_SLOT(handleSavePointLeft()));
+    connect(this,TQ_SIGNAL(SCN_UPDATEUI()),
+             TQ_SLOT(handleUpdateUI()));
+    connect(this,TQ_SIGNAL(TQSCN_SELCHANGED(bool)),
+             TQ_SLOT(handleSelectionChanged(bool)));
+    connect(this,TQ_SIGNAL(SCN_USERLISTSELECTION(const char *,int)),
+             TQ_SLOT(handleUserListSelection(const char *,int)));
 
     // Set the default font.
     setFont(TQApplication::font());
@@ -2412,16 +2412,16 @@ void TQextScintilla::setLexer(TQextScintillaLexer *lexer)
 
         SendScintilla(SCI_SETSTYLEBITS,bits);
 
-        connect(lex,TQT_SIGNAL(colorChanged(const TQColor &,int)),
-            TQT_SLOT(handleStyleColorChange(const TQColor &,int)));
-        connect(lex,TQT_SIGNAL(eolFillChanged(bool,int)),
-            TQT_SLOT(handleStyleEolFillChange(bool,int)));
-        connect(lex,TQT_SIGNAL(fontChanged(const TQFont &,int)),
-            TQT_SLOT(handleStyleFontChange(const TQFont &,int)));
-        connect(lex,TQT_SIGNAL(paperChanged(const TQColor &,int)),
-            TQT_SLOT(handleStylePaperChange(const TQColor &,int)));
-        connect(lex,TQT_SIGNAL(propertyChanged(const char *,const char *)),
-            TQT_SLOT(handlePropertyChange(const char *,const char *)));
+        connect(lex,TQ_SIGNAL(colorChanged(const TQColor &,int)),
+            TQ_SLOT(handleStyleColorChange(const TQColor &,int)));
+        connect(lex,TQ_SIGNAL(eolFillChanged(bool,int)),
+            TQ_SLOT(handleStyleEolFillChange(bool,int)));
+        connect(lex,TQ_SIGNAL(fontChanged(const TQFont &,int)),
+            TQ_SLOT(handleStyleFontChange(const TQFont &,int)));
+        connect(lex,TQ_SIGNAL(paperChanged(const TQColor &,int)),
+            TQ_SLOT(handleStylePaperChange(const TQColor &,int)));
+        connect(lex,TQ_SIGNAL(propertyChanged(const char *,const char *)),
+            TQ_SLOT(handlePropertyChange(const char *,const char *)));
 
         SendScintilla(SCI_SETLEXERLANGUAGE,lex -> lexer());
 
